
function drawTree(svg, root) {
    // svg should be a d3 selection
    if (!(svg instanceof d3.selection)) {
        console.log("Warning: Must have D3 selections to draw tree.");
        return;
    }

    // x, y accessors to make our lives easier later on
    // e.g. swap order to swap orientation
    // e.g. convert between cartesian/polar for circular layouts
    var x = function(d) { return d.x; };
    var y = function(d) { return d.y; };

    // cartesian layout (try cluster() vs tree() layouts)
    var layout = d3.layout
        .cluster()
        // .tree()
        .size([1200, 500]);

    // polar/radial layout
    // we use x for degrees and y for radial
    // (the 360 value is degrees)
    // layout = d3.layout.cluster().size([360, 250]);

    // x = function(d) {
    //     // function takes radial then degree
    //     return toCartesian(d.y, d.x).x;
    // };

    // y = function(d) {
    //     // function takes radial then degree
    //     return toCartesian(d.y, d.x).y;
    // };

    // curvy lines
    var path = d3.svg.diagonal()
        // need to know how to get out x/y values from data
        // uses our handy accessors
        .projection(function(d) {
            return [x(d), y(d)];
        });

    // straight lines
    // var line = d3.svg.line()
    //     .interpolate("linear")
    //     .x(x)
    //     .y(y);

    // svg.line is not made to work with source and target properties
    // only works with an array of points

    // var path = function(d) {
    //     // create array of points for line generator
    //     return line([d.source, d.target]);
    // };

    // look at original data before layout
    console.log(root);

    // use layout to generate node positions
    // note: this adds an x, y property to your data!
    var nodes = layout.nodes(root);

    // use layout to generate links between nodes
    // based on the nested hierarchy in the json
    var links = layout.links(nodes);

    // look at what gets added to nodes and links
    console.log(nodes[0]);
    console.log(links[0]);

    // draw links first, then nodes on top
    svg.selectAll("path")
        // use links created by layout
        .data(links)
        .enter()
        .append("path")
        .attr("class", "link")
        // use path generator
        .attr("d", path);

    svg.selectAll("circle")
        // use nodes created by layout
        .data(nodes)
        .enter()
        .append("circle")
        .attr("class", "node")
        .attr("r", 4)
        // use x/y accessors
        .attr("cx", x)
        .attr("cy", y);
}
